clear all
close all
clc

%% Measurements
load ('12LED_15.1V_1.24A_2steps.mat')
%load ('12LED_14.5V_0.94A_2steps.mat')
%%
% define range
x_start = 2;
x_end = 51;
y_start = 7;
y_end = 56;
meandata2=meandata(x_start:x_end,y_start:y_end);
%% create a circular mask matrix
x = -0.5*(x_end-x_start)+0.5:0.5*(x_end-x_start)+0.5; %define x and y coordinate. Shu: It has +0.5 because the plot is not starting from 0,0.
y =  -0.5*(y_end-y_start)+0.5:0.5*(y_end-y_start)+0.5; 
[xx yy] = meshgrid(x,y); % create 2d grid coordinates
mask = zeros(size(xx)); %create the mask of right size, filled with zeros
pix2mm=0.5; %the scaling between pixels and mm: one pixel is 0.5x0.5 cm^2
radius = 20*pix2mm; %10 [mm]?
mask_radius = radius/pix2mm; %define radius of the masking circle. Shu: this is for meandata in pixels and the radius before was for the data in mm
mask((xx.^2+yy.^2)<mask_radius^2)=1; %all values within the circle become one
mask = logical(mask); %tell matlab it is a mask
inv_mask = ~mask; %make an inverted mask
%%
meandata2=meandata2(mask);
%% plot the circle and area of interest

totalirradiation=173/1000; %[W] 16  mW  for 5 mW/cm2, 32 for 10, 67 for 21, 113 for 35 and 173 for 55
diameter=2/100; %[m] it is 20 mm the optical window diameter
area= pi*(diameter/2)^2; % [m2]
power=totalirradiation/area %to get W/m2 
totalpixel=sum(sum(meandata2)); %all the values in the circle
irradiation = meandata*totalirradiation/totalpixel/((pix2mm/1000)^2);% to calculate W.m^-2 because 1 pixel is 0.5 mm
irradiation_in_circle = meandata2*totalirradiation/totalpixel/((pix2mm/1000)^2);% irradiation only in the circle
circlevar = irradiation(x_start:x_end,y_start:y_end);%to plot the area we want to see

sum(irradiation_in_circle)*((pix2mm/1000)^2)%to check it is okay, should be equal to totalirradiation
%plot data
figure;
%subplot(1,2,2)
X = 0:1:length(circlevar)-1;
X = X*pix2mm;
Y=X;
handle=pcolor(X,Y,circlevar);
set(handle,'LineStyle','none'); %to remove the squares in the plot
hcb=colorbar;

% map=gray.*[.56 0.58 1];
% colormap(map)

%For article Font 16 and 18 title, for GA 24 and 26
set(hcb, 'FontSize', 16);
set(get(hcb,'label'),'string','Irradiation [W.m^{-2}]');%,'FontSize', 18);
hx=xlabel('Position [mm]');
set(hx, 'FontSize', 16);
hy=ylabel('Position [mm]');
set(hy, 'FontSize', 16);
axis equal;
xlim([1 24])
caxis([1 700])
% title('5 mW/cm^{2}');
%title('16 mW <> 5 mW.cm^{-2}','FontSize', 20);%16  mW  for 5 mW/cm2
%title('32 mW <> 10 mW.cm^{-2}','FontSize', 20)%32 for 10
%title('67 mW <> 21 mW.cm^{-2}','FontSize', 20) %67 for 21
%title('113 mW <> 35 mW.cm^{-2}','FontSize', 20) %113 for 35
%title('Multi-LED 173 mW <> 550 W.m^{-2}','FontSize', 26)%173 for 55
% title('Multi-LED 550 W.m^{-2}','FontSize', 26)
% title('Multi-LED 66 mW <> 210 W.m^{-2}','FontSize', 18)
title('Multi-LED 173 mW <> 550 W.m^{-2}','FontSize', 18)
text(0,25.6,'e)','FontSize',18);
% plot circle
x_center = (0.5*(x_end-x_start))*pix2mm; %multiply by 0.5 because the center is the diameter/2, +1 in included because the plot starts at 1,1 instead of 0,0 so we need to compensate for that.
y_center = (0.5*(y_end-y_start))*pix2mm;
% define circle
theta = [0:0.001:2*pi];
% determine x and y position of circle
x = radius * cos(theta) + x_center; %to plot the cirlce with the mcenter being the middle of the image
y = radius * sin(theta) + y_center;
% plot the circle
hold on
plot(x,y,'k.','Markersize',10)
% axis equal

%% calculate mean of the masked value
mean_value = mean(circlevar(mask))
min_value =min(circlevar(mask))
max_value =max(circlevar(mask))
std_value=std(circlevar(mask))
%% uniformity
uniformity=1-((sum(abs(circlevar(mask)-mean_value)))/(2*mean_value*numel(circlevar(mask))))
uniformity2=1-((sum(abs(circlevar(mask)-mean_value)))/(2*(sum(abs(circlevar(mask))))))
%%
figure;
set(gcf,'position',[0,0,450,390])
width = 50; %set width of the bins
edges = 0:width:700; %define bin edges
bincenters = edges(1:end-1)+(width/2); %define where the centers of the bins are
colors = colormap; %get the colormap used in the pcolor plot
%now we link the irradiation values to the individual colors: colors is a
%list of 256 colors (length(colors)), with the irradiation running from 0
%to 650. Now we have a list of colors and a list of corresponding
%irradiations
colorsindices = linspace(0,700,length(colors)); 
%pick or interpolate the values of the centers of the bins from the list of
%colors. so we get the colors that correspond to the bincenters
%(irradiations)
pickedcolors = interp1(colorsindices,colors,bincenters);

%instead of histogram we use histcounts, which does the same but doesnt
%plot it. Basically it is h.Values
hc = histcounts(circlevar(mask),edges,'Normalization','probability'); 
%we plot a bar graph, and specify that we want to have colors
% b = bar(bincenters,hc,1,'facecolor', 'flat','edgecolor', 'flat');
b = bar(bincenters,hc,1,'facecolor', 'flat');
%we link to colors of the bars to the colors we picked from the colormap
%before
b.CData = pickedcolors;
%we set the values on the xaxis like we like it
set(gca,'XTick',edges);
xlabel('Irradiation [W.m^{-2}]','FontSize', 16);
ylabel('Area fraction','FontSize', 16);
xlim([0 700])
ylim([0 1])
text(0,1.05,'f)','FontSize',18);
text(310,0.84,'Multi-LED Lamp','FontSize',18);
%text(290,0.78,'66 mW <> 210 W.m^{-2}','FontSize',16);
text(290,0.78,'173 mW <> 550 W.m^{-2}','FontSize',16);
%grid on
box on
